use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.007006
use Test::Spelling 0.17;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib ) );
__DATA__
49699333
Actions
Alders
Alders'
Alessandro
Andreas
Assets
Assignees
Atria
Base
Bessarabov
Blobs
Bowen
Brand
Collaborators
Comments
Commits
Contents
Corey
DUPONCHELLE
Downloads
Emails
Events
Farwell
Florian
Followers
Forks
Ghedini
Gists
GitData
Graham
Hooks
Html
Huß
Ichinose
Issues
Ivan
JSONP
Joaquín
Johannes
José
Keys
Konboi
LRU
Labels
Legge
Marienborg
Markdown
Masashi
Members
Merijn
Michael
Milestones
OAuth
Olaf
Ollis
Orgs
Pithub
Plunien
PullRequests
Ragwitz
Randy
References
Releases
Repos
Result
ResultSet
Reviewers
Rich
Roland
SHAs
SUZUKI
Schwern
Search
SearchV3
SharedCache
Shogo
Starring
Stats
Statuses
Stauner
Stevan
Tags
Teams
Thibault
Timothy
Trees
Tux
Unfollow
Unstar
Users
Watching
Workflows
Znet
Zoffix
alessandro
andreas
api
asc
assignees
coreyf
cpan
dependabot
desc
etag
getLength
getNext
gfm
gists
gollum
html
ie
ivan
jjatria
lib
linux
losslessly
m15
md
olaf
orgs
params
perlancar
plicease
plu
rafl
randy
ratelimit
rbowen
readme
repos
rhuss
ryosuke
schwern
sha
shogo82148
submodule
teckl
teckl1979
thibault
timlegge
ua
unfollow
unstar
zipball
